==> sieve_chem_file_formats-0.1.0-py3-none-any.whl: sieve_chem_file_formats/pdb.py <==
from __future__ import annotations
from typing import TYPE_CHECKING, Dict, Any, Optional, Tuple, List
if TYPE_CHECKING:
    pass

from dataclasses import dataclass


@dataclass
class AtomOrHetatmRecord:
    """
    Represents an ATOM or HETATM record from a PDB file.
    """
    record_type: str
    atom_serial_num: int
    atom_name: str
    alt_location_indicator: str
    residue_name: str
    chain_id: str
    residue_seq_num: int
    code_for_insertion_of_residues: str
    x: float
    y: float
    z: float
    occupancy: float
    temp_factor: float
    segment_id: str
    element_symbol: str
    charge: str

    def __repr__(self):
        # Format fields based on PDB column alignment
        return (
            f'{self.record_type:<6}'  # Record type, left-justified (columns 1-6)
            f'{self.atom_serial_num:>5}'  # Atom serial number, right-justified (columns 7-11)
            f' {self.atom_name:<4}'  # Atom name, left-justified (columns 13-16)
            f'{self.alt_location_indicator:1}'  # Alternate location indicator (column 17)
            f'{self.residue_name:>3}'  # Residue name, right-justified (columns 18-20)
            f' {self.chain_id:1}'  # Chain identifier (column 22)
            f'{self.residue_seq_num:>4}'  # Residue sequence number, right-justified (columns 23-26)
            f'{self.code_for_insertion_of_residues:1}'  # Code for insertions of residues (column 27)
            f'   '  # Blank columns (28-30)
            f'{self.x:>8.3f}'  # X coordinate, right-justified, 8.3 format (columns 31-38)
            f'{self.y:>8.3f}'  # Y coordinate, right-justified, 8.3 format (columns 39-46)
            f'{self.z:>8.3f}'  # Z coordinate, right-justified, 8.3 format (columns 47-54)
            f'{self.occupancy:>6.2f}'  # Occupancy, right-justified, 6.2 format (columns 55-60)
            f'{self.temp_factor:>6.2f}'  # Temperature factor, right-justified, 6.2 format (columns 61-66)
            f'          '  # Blank columns (67-72)
            f'{self.element_symbol:>2}'  # Element symbol, right-justified (columns 77-78)
            f'{self.charge:>2}'  # Charge, right-justified (columns 79-80)
        )

    @classmethod
    def from_pdb_line(cls, line: str) -> AtomOrHetatmRecord:
        """
        Parses record from a ATOM or HETATM line in a PDB file.

        :param line: ATOM or HETATM line in a PDB file.
        :return: AtomOrHetatmRecord object.
        """
        return AtomOrHetatmRecord(
            record_type=line[:6].strip(),
            atom_serial_num=int(line[6:11].strip()),
            atom_name=line[12:16].strip(),
            alt_location_indicator=line[16].strip(),
            residue_name=line[17:20].strip(),
            chain_id=line[21].strip(),
            residue_seq_num=int(line[22:26].strip()),
            code_for_insertion_of_residues=line[26].strip(),
            x=float(line[30:38].strip()),
            y=float(line[38:46].strip()),
            z=float(line[46:54].strip()),
            occupancy=float(line[54:60].strip()),
            temp_factor=float(line[60:66].strip()),
            segment_id=line[72:76].strip(),
            element_symbol=line[76:78].strip(),
            charge=line[78:80].strip(),
        )


def parse_models(pdb_file: str) -> List[List[AtomOrHetatmRecord]]:
    """
    Parses models (poses) from a PDB file.

    :param pdb_file: Path to the PDB file.
    :return: List of models, where each model is a list of AtomOrHetatmRecord objects.
    """
    models = []
    current_model = []

    with open(pdb_file, 'r') as f:
        for line in f:
            if line.startswith('MODEL'):
                current_model = []
            elif line.startswith('ATOM') or line.startswith('HETATM'):
                current_model.append(AtomOrHetatmRecord.from_pdb_line(line))
            elif line.startswith('ENDMDL'):
                models.append(current_model)

    return models

==> sieve_chem_file_formats-0.1.1-py3-none-any.whl: sieve_chem_file_formats/pdb.py <==
from __future__ import annotations

from dataclasses import dataclass


@dataclass
class AtomOrHetatmRecord:
    """
    Represents an ATOM or HETATM record from a PDB file.
    """
    record_type: str
    atom_serial_num: int
    atom_name: str
    alt_location_indicator: str
    residue_name: str
    chain_id: str
    residue_seq_num: int
    code_for_insertion_of_residues: str
    x: float
    y: float
    z: float
    occupancy: float
    temp_factor: float
    segment_id: str
    element_symbol: str
    charge: str

    def __repr__(self):
        # Format fields based on PDB column alignment
        return (
            f'{self.record_type:<6}'  # Record type, left-justified (columns 1-6)
            f'{self.atom_serial_num:>5}'  # Atom serial number, right-justified (columns 7-11)
            f' {self.atom_name:<4}'  # Atom name, left-justified (columns 13-16)
            f'{self.alt_location_indicator:1}'  # Alternate location indicator (column 17)
            f'{self.residue_name:>3}'  # Residue name, right-justified (columns 18-20)
            f' {self.chain_id:1}'  # Chain identifier (column 22)
            f'{self.residue_seq_num:>4}'  # Residue sequence number, right-justified (columns 23-26)
            f'{self.code_for_insertion_of_residues:1}'  # Code for insertions of residues (column 27)
            f'   '  # Blank columns (28-30)
            f'{self.x:>8.3f}'  # X coordinate, right-justified, 8.3 format (columns 31-38)
            f'{self.y:>8.3f}'  # Y coordinate, right-justified, 8.3 format (columns 39-46)
            f'{self.z:>8.3f}'  # Z coordinate, right-justified, 8.3 format (columns 47-54)
            f'{self.occupancy:>6.2f}'  # Occupancy, right-justified, 6.2 format (columns 55-60)
            f'{self.temp_factor:>6.2f}'  # Temperature factor, right-justified, 6.2 format (columns 61-66)
            f'          '  # Blank columns (67-72)
            f'{self.element_symbol:>2}'  # Element symbol, right-justified (columns 77-78)
            f'{self.charge:>2}'  # Charge, right-justified (columns 79-80)
        )

    @classmethod
    def from_pdb_line(cls, line: str) -> AtomOrHetatmRecord:
        """
        Parses record from a ATOM or HETATM line in a PDB file.

        :param line: ATOM or HETATM line in a PDB file.
        :return: AtomOrHetatmRecord object.
        """
        return AtomOrHetatmRecord(
            record_type=line[:6].strip(),
            atom_serial_num=int(line[6:11].strip()),
            atom_name=line[12:16].strip(),
            alt_location_indicator=line[16].strip(),
            residue_name=line[17:20].strip(),
            chain_id=line[21].strip(),
            residue_seq_num=int(line[22:26].strip()),
            code_for_insertion_of_residues=line[26].strip(),
            x=float(line[30:38].strip()),
            y=float(line[38:46].strip()),
            z=float(line[46:54].strip()),
            occupancy=float(line[54:60].strip()),
            temp_factor=float(line[60:66].strip()),
            segment_id=line[72:76].strip(),
            element_symbol=line[76:78].strip(),
            charge=line[78:80].strip(),
        )


def parse_models(pdb_file: str) -> list[list[AtomOrHetatmRecord]]:
    """
    Parses models (poses) from a PDB file.

    :param pdb_file: Path to the PDB file.
    :return: List of models, where each model is a list of AtomOrHetatmRecord objects.
    """
    models = []
    current_model = []

    with open(pdb_file, 'r') as f:
        for line in f:
            if line.startswith('MODEL'):
                current_model = []
            elif line.startswith('ATOM') or line.startswith('HETATM'):
                current_model.append(AtomOrHetatmRecord.from_pdb_line(line))
            elif line.startswith('ENDMDL'):
                models.append(current_model)

    return models
